==> esp8266-0.3.0.crate: esp8266-0.3.0/src/timer/frc2_alarm.rs <==
#[doc = "Register `FRC2_ALARM` reader"]
pub struct R(crate::R<FRC2_ALARM_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FRC2_ALARM_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<FRC2_ALARM_SPEC>> for R {
    fn from(reader: crate::R<FRC2_ALARM_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `FRC2_ALARM` writer"]
pub struct W(crate::W<FRC2_ALARM_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<FRC2_ALARM_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<FRC2_ALARM_SPEC>> for W {
    fn from(writer: crate::W<FRC2_ALARM_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `frc2_alarm` reader - the alarm value for the counter"]
pub struct FRC2_ALARM_R(crate::FieldReader<u32, u32>);
impl FRC2_ALARM_R {
    pub(crate) fn new(bits: u32) -> Self {
        FRC2_ALARM_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FRC2_ALARM_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `frc2_alarm` writer - the alarm value for the counter"]
pub struct FRC2_ALARM_W<'a> {
    w: &'a mut W,
}
impl<'a> FRC2_ALARM_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | ((value as u32) & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - the alarm value for the counter"]
    #[inline(always)]
    pub fn frc2_alarm(&self) -> FRC2_ALARM_R {
        FRC2_ALARM_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - the alarm value for the counter"]
    #[inline(always)]
    pub fn frc2_alarm(&mut self) -> FRC2_ALARM_W {
        FRC2_ALARM_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "the alarm value for the counter\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_alarm](index.html) module"]
pub struct FRC2_ALARM_SPEC;
impl crate::RegisterSpec for FRC2_ALARM_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [frc2_alarm::R](R) reader structure"]
impl crate::Readable for FRC2_ALARM_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [frc2_alarm::W](W) writer structure"]
impl crate::Writable for FRC2_ALARM_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets FRC2_ALARM to value 0"]
impl crate::Resettable for FRC2_ALARM_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/timer/frc2_alarm.rs <==
#[doc = "Register `FRC2_ALARM` reader"]
pub struct R(crate::R<FRC2_ALARM_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FRC2_ALARM_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FRC2_ALARM_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FRC2_ALARM_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `FRC2_ALARM` writer"]
pub struct W(crate::W<FRC2_ALARM_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<FRC2_ALARM_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<FRC2_ALARM_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<FRC2_ALARM_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `frc2_alarm` reader - the alarm value for the counter"]
pub struct FRC2_ALARM_R(crate::FieldReader<u32, u32>);
impl FRC2_ALARM_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        FRC2_ALARM_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FRC2_ALARM_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `frc2_alarm` writer - the alarm value for the counter"]
pub struct FRC2_ALARM_W<'a> {
    w: &'a mut W,
}
impl<'a> FRC2_ALARM_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - the alarm value for the counter"]
    #[inline(always)]
    pub fn frc2_alarm(&self) -> FRC2_ALARM_R {
        FRC2_ALARM_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - the alarm value for the counter"]
    #[inline(always)]
    pub fn frc2_alarm(&mut self) -> FRC2_ALARM_W {
        FRC2_ALARM_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "the alarm value for the counter\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_alarm](index.html) module"]
pub struct FRC2_ALARM_SPEC;
impl crate::RegisterSpec for FRC2_ALARM_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [frc2_alarm::R](R) reader structure"]
impl crate::Readable for FRC2_ALARM_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [frc2_alarm::W](W) writer structure"]
impl crate::Writable for FRC2_ALARM_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets FRC2_ALARM to value 0"]
impl crate::Resettable for FRC2_ALARM_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
